Release History
===============

version 0.3
-----------
* `DynapcnnCompatibleNetwork` is now deprecated in favor of `DynapcnnNetwork`. This is a cosmetic name change while the new class is functionally equivalent. Please change to this new class name.
* Module paths `dvslayer` and `todynapcnn` have changed to `dvs_layer` and `dynapcnn_network` respectively. This affects mostly internal code that is not user-facing.
